@@ -5,23 +5,23 @@ context('pdata(), qdata(), and rdata()')
 test_that("formula interface works.", {
 	expect_equivalent( length(rdata( ~age, 10, data = mosaicData::HELPrct)), 10 )
 	expect_equivalent( pdata( ~age, 30, data = mosaicData::HELPrct), prop( ~ mosaicData::HELPrct$age <= 30) )
-	expect_equivalent( qdata( ~age, .75, mosaicData::HELPrct)['quantile'], quantile(mosaicData::HELPrct$age, .75) )
-	expect_equivalent( qdata(~ age, c(.25,.75), mosaicData::HELPrct)$quantile, quantile(mosaicData::HELPrct$age, c(.25,.75)) )
+	expect_equivalent( qdata( ~age, .75, mosaicData::HELPrct), quantile(mosaicData::HELPrct$age, .75) )
+	expect_equivalent( qdata(~ age, c(.25,.75), mosaicData::HELPrct), quantile(mosaicData::HELPrct$age, c(.25,.75)) )
 })
 
 test_that("vector/data interface works.", {
-	expect_equivalent( length(rdata( age, 10, mosaicData::HELPrct)), 10 )
-	expect_equivalent( pdata(age, 30, data = mosaicData::HELPrct), prop(~ mosaicData::HELPrct$age <= 30) )
-	expect_equivalent( qdata(age, .75, data = mosaicData::HELPrct)['quantile'], quantile(mosaicData::HELPrct$age, .75) )
-	expect_equivalent( qdata(~age, c(.25,.75), data = mosaicData::HELPrct)$quantile, quantile(mosaicData::HELPrct$age, c(.25,.75)) )
+	expect_equivalent( length(rdata( mosaicData::HELPrct$age, 10, mosaicData::HELPrct)), 10 )
+	expect_equivalent( pdata(mosaicData::HELPrct$age, 30, data = mosaicData::HELPrct), prop(~ mosaicData::HELPrct$age <= 30) )
+	expect_equivalent( qdata(mosaicData::HELPrct$age, .75, data = mosaicData::HELPrct), quantile(mosaicData::HELPrct$age, .75) )
+	expect_equivalent( qdata(mosaicData::HELPrct$age, c(.25,.75), data = mosaicData::HELPrct), quantile(mosaicData::HELPrct$age, c(.25,.75)) )
 })
 
 
 test_that("vector (no data) interface works.", {
 	expect_equivalent( length(rdata( n = 10, mosaicData::HELPrct$age)), 10 )
 	expect_equivalent( pdata(mosaicData::HELPrct$age, 30), prop( ~ mosaicData::HELPrct$age <= 30) )
-	expect_equivalent( qdata(mosaicData::HELPrct$age, .75)['quantile'], quantile(mosaicData::HELPrct$age, .75) )
-	expect_equivalent( qdata( p = c(.25,.75), mosaicData::HELPrct$age)$quantile, 
+	expect_equivalent( qdata(mosaicData::HELPrct$age, .75), quantile(mosaicData::HELPrct$age, .75) )
+	expect_equivalent( qdata( p = c(.25,.75), mosaicData::HELPrct$age), 
 	                   quantile(mosaicData::HELPrct$age, c(.25,.75)) )
 })
 
